# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-IO-Socket-IP
Version:	0.42
Release:	1.%{__distinit}%{__distvers}
Summary:	Drop-in replacement for IO::Socket::INET supporting both IPv4 and IPv6
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/IO-Socket-IP
Source0:	https://cpan.metacpan.org/modules/by-module/IO/IO-Socket-IP-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(:VERSION) >= 5.14.0
BuildRequires:	perl(Module::Build)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Errno)
BuildRequires:	perl(IO::Socket)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(Socket) >= 1.97
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(IO::Socket::INET)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(Test::Pod) >= 1.00
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
# Old provides generator does not support the syntax used in this module
%if 0%{?fedora} < 21 && 0%{?rhel} < 8
Provides:	perl(IO::Socket::IP) = %{version}
%endif

%description
This module provides a protocol-independent way to use IPv4 and IPv6
sockets, as a drop-in replacement for IO::Socket::INET. Most constructor
arguments and methods are provided in a backward-compatible way.

%prep
%setup -q -n IO-Socket-IP-%{version}

# Get rid of bogus exec permissions
find . -type f | xargs chmod -c -x

%build
perl Build.PL --installdirs=vendor
./Build

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%{_fixperms} -c %{buildroot}

%check
./Build test

%files
%license LICENSE
%doc Changes examples README
%{perl_vendorlib}/IO/
%{_mandir}/man3/IO::Socket::IP.3*

%changelog
* Tue Jul 25 2023 Paul Howarth <paul@city-fan.org> - 0.42-1
- Update to 0.42
  - Put error string in `$IO::Socket::errstr` as done by IO::Socket v1.45
  - Updated for Perl v5.14 - use 'package NAME VERSION' syntax
  - Fix typo 'behvior' (CPAN RT#133467)
  - Fix for DragonflyBSD and IPV6_V6ONLY from core perl (CPAN RT#148293)
- Manually add provides for Perl 5.14 package syntax not handled by
  provides generator on old distributions

* Tue Mar 28 2023 Paul Howarth <paul@city-fan.org> - 0.41-492
- Drop build dependency on perl(Socket6); IPv6 supported in perl(Socket)
- Use SPDX-format license tag
- Use %%license unconditionally

* Wed Sep 16 2020 Paul Howarth <paul@city-fan.org> - 0.41-1
- Update to 0.41
  - Don't ship a Makefile.PL
  - Updated docs about '-register' option
  - Ensure safety under default-strict (CPAN RT#133322)
  - Updated to '=head2 barename' documentation style
  - Remember to declare configure_requires Module::Build
- Switch upstream from search.cpan.org to metacpan.org

* Sat Apr 28 2018 Paul Howarth <paul@city-fan.org> - 0.39-5
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop legacy Group: tag

* Tue Mar  7 2017 Paul Howarth <paul@city-fan.org> - 0.39-1
- Update to 0.39
  - Handle EOPNOTSUPP in response of efforts to disable V6ONLY (CPAN RT#119780)

* Wed Aug  3 2016 Paul Howarth <paul@city-fan.org> - 0.38-1
- Update to 0.38
  - Support setting custom socket options with new 'Sockopts' constructor
    parameter
  - Restore blocking mode after ->connect errors (CPAN RT#112334)
- BR: perl-generators where available

* Wed Jun 17 2015 Paul Howarth <paul@city-fan.org> - 0.37-2
- Perl 5.22 rebuild

* Fri Mar 13 2015 Paul Howarth <paul@city-fan.org> - 0.37-1
- Update to 0.37
  - Earlier detection/reporting of erroneous Listen + Peer* argument
    combination; don't rely on resolveable hostname to do it (CPAN RT#92930)
  - Skip t/16v6only.t on irix (CPAN RT#102662)
  - Remember to eval() $IO::Socket::VERSION in case it's a devel release
    (CPAN RT#101954)
  - s/Port/LocalPort/ in unit tests (CPAN RT#96064)

* Sun Jan 11 2015 Paul Howarth <paul@city-fan.org> - 0.36-1
- Update to 0.36
  - Always bind() on MSWin32 because Windows doesn't like it if we listen()
    having not done so (CPAN RT#101396)

* Tue Jan  6 2015 Paul Howarth <paul@city-fan.org> - 0.35-1
- Update to 0.35
  - Restore blocking mode after timeout connect immediate success
    (CPAN RT#100947)
  - Avoid CORE:: prefixing so global override modules work (CPAN RT#101174)
  - Ensure that ->peer{host,port,hostname,service} never die even when
    unconnected (CPAN RT#98759)

* Wed Dec  3 2014 Paul Howarth <paul@city-fan.org> - 0.34-1
- Update to 0.34
  - Don't select() for read-readiness when waiting for non-blocking connect()
    because it upsets VMS (CPAN RT#100654)

* Fri Nov 21 2014 Paul Howarth <paul@city-fan.org> - 0.33-1
- Update to 0.33
  - Use SOL_SOCKET/SO_ERROR sockopt rather than 2nd connect() error hoisting
    to detect nonblocking connect/failure when implementing Timeout
    (CPAN RT#98976)

* Sun Sep 21 2014 Paul Howarth <paul@city-fan.org> - 0.32-1
- Update to 0.32
  - Implementation of Timeout for ->connect (CPAN RT#92075)
- Classify buildreqs by usage

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 0.31-2
- Use %%license where possible

* Fri Jul 11 2014 Paul Howarth <paul@city-fan.org> - 0.31-1
- Update to 0.31
  - A better fix for subclassing ->connect (CPAN RT#95983) because 0.30 broke
    the way IO::Socket::SSL works (CPAN RT#97050)

* Fri Jul  4 2014 Paul Howarth <paul@city-fan.org> - 0.30-1
- Update to 0.30
  - Invoke $self->connect fully-qualified in case of subclasses with override
    (CPAN RT#95983)
  - Added extra diag() call in t/15io-socket.t (CPAN RT#96914)

* Mon Feb 24 2014 Paul Howarth <paul@city-fan.org> - 0.29-1
- Update to 0.29
  - Workaround for OSes that disobey AI_ADDRCONFIG and yield AIs on families
    the kernel will not support anyway (e.g. HPUX)
  - Workaround for OSes that lack getprotobyname() (e.g. Android)

* Tue Feb 11 2014 Paul Howarth <paul@city-fan.org> - 0.28-1
- Update to 0.28
  - Renamed internal _configure method to _io_socket_ip__configure to avoid
    clashes with modules that try to subclass IO::Socket::INET
  - Disable AI_ADDRCONFIG during one-sided 'v6 tests as sometimes it would
    otherwise fail
  - Skip the SO_BROADCAST test on OSes that fail with EACCES (CPAN RT#92502)

* Tue Jan 21 2014 Paul Howarth <paul@city-fan.org> - 0.27-1
- Update to 0.27
  - Apply a short timeout to unit tests that probe for Internet connectivity,
    in case of bad firewalls, etc. (Perl RT#121037)
  - Defend against machines with IN6ADDR_LOOPBACK not being "::1" in unit
    tests, similar to the INADDR_LOOPBACK case (CPAN RT#92295)

* Thu Jan 16 2014 Paul Howarth <paul@city-fan.org> - 0.26-1
- Update to 0.26
  - Set $VERSION in BEGIN block before 'use base' so that
    Acme::Override::INET still works
  - Various minor improvements to documentation

* Sun Jan 12 2014 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25
  - Allow both *Host with port and *Port arguments, letting port from Host
    argument take precedence (INET compat)
  - Ensure that a Host/Family-less constructor still constructs a socket, by
    using gai()s AI_ADDRCONFIG hint

* Thu Sep 19 2013 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24
  - Defend against INADDR_LOOPBACK not being 127.0.0.1 on machines with odd
    networking (e.g. FreeBSD jails) during unit testing

* Wed Sep 11 2013 Paul Howarth <paul@city-fan.org> - 0.23-1
- Update to 0.23
  - Check that kernel actually supports SO_REUSEPORT before unit-testing it
    (CPAN RT#86177)

* Fri Jul 26 2013 Paul Howarth <paul@city-fan.org> - 0.22-1
- Update to 0.22
  - Always pass 'socktype' hint to getaddrinfo() in unit tests because some
    OSes get upset without it
  - Don't unit-test that sockaddr is updated with a local bind() on SOCK_DGRAM
    sockets because some OSes don't

* Sun Jul 21 2013 Paul Howarth <paul@city-fan.org> - 0.21-3
- Perl 5.18 rebuild

* Thu Apr 25 2013 Paul Howarth <paul@city-fan.org> - 0.21-1
- Update to 0.21
  - Provide a downgrade method to turn an AF_INET-domain socket into a real
    IO::Socket::INET instance
  - Ensure that IO::Socket->new( Domain => ... ) definitely returns a socket
    in the right family

* Tue Apr 16 2013 Paul Howarth <paul@city-fan.org> - 0.20-1
- Update to 0.20
  - Skip the IPV6_V6ONLY tests on machines lacking that constant
  - Avoid Socket::inet_pton() in unit tests as Strawberry lacks it
  - Added ->join_addr
  - Respect subclassing argument to ->accept

* Tue Mar 12 2013 Paul Howarth <paul@city-fan.org> - 0.19-1
- Update to 0.19
  - More IO::Socket::INET compatibility fixes:
    - Ensure ->connected is false after ->close
    - Ensure that IO::Socket::IP->new(Family => $family) still creates an
      unbound, unconnected socket filehandle

* Fri Nov 30 2012 Paul Howarth <paul@city-fan.org> - 0.18-1
- Update to 0.18
  - Work around ->socktype being undef on IO::Socket versions before 1.35 by
    fetching ->sockopt( SO_TYPE ) (CPAN RT#81549)
  - Fix test skip counts in t/21nonblocking-connect-internet.t (CPAN RT#79393)

* Mon Aug 20 2012 Paul Howarth <paul@city-fan.org> - 0.17-1
- Update to 0.17
  - Only pass AI_ADDRCONFIG as getaddrinfo() flag if no other flags are
    specified, so the caller can disable it if required
  - Don't count select() invocations during nonblocking unit test because this
    is too unreliable and races with the kernel/TCP stack

* Sun Jun 24 2012 Paul Howarth <paul@city-fan.org> - 0.16-1
- Update to 0.16
  - Don't ->close after all connect attempts fail, because IO::Socket::INET
    doesn't do that

* Wed Jun 20 2012 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15
  - (Hopefully) improved ->connect logic for better MSWin32 support
  - Skip testing AI_NUMERICSERV on OSes that don't support it

* Mon Jun 18 2012 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14
  - Second attempt at fixing test skip counts

* Sun Jun 17 2012 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13
  - Update test skip counts in unit tests so they match the number of tests
    actually skipped

* Fri Jun 15 2012 Paul Howarth <paul@city-fan.org> - 0.12-1
- Import from Fedora
- Update to 0.12
  - Ensure that all instances have a defined fileno after construction, even
    in non-blocking mode (CPAN RT#77726)

* Wed Jun 06 2012 Petr Šabata <contyk@redhat.com> - 0.11-1
- 0.11 bump

* Fri May 11 2012 Petr Šabata <contyk@redhat.com> - 0.10-1
- 0.10 bump

* Wed Mar 14 2012 Petr Šabata <contyk@redhat.com> - 0.09-1
- 0.09 bump

* Fri Jan 27 2012 Petr Šabata <contyk@redhat.com> - 0.08-1
- Specfile autogenerated by cpanspec 1.78
